@@ -8,7 +8,7 @@ from typing import Optional
 from .runner import run_test
 from .analyzer import aggregate_analyses, enhanced_analyze_trace
 from .reporter import print_report, print_aggregate_report
-from .submission import ResultSubmitter
+from .submission import ResultSubmitter, _is_development_mode
 from .models import TestResult
 from . import __version__
 
@@ -30,16 +30,26 @@ async def show_community_comparison(tool: str, scenario: str, user_duration: flo
             else:
                 return  # No community data available
         
-        # Extract community metrics
-        community_success_rate = scenario_stats.get('success_rate', 0)
-        if community_success_rate <= 1:
-            community_success_rate *= 100  # Convert to percentage
+        # Extract community metrics with normalization
+        def normalize_success_rate(rate):
+            if rate is None:
+                return 0.0
+            if rate <= 1:
+                return rate * 100  # Convert from decimal to percentage
+            return rate  # Already in percentage format
+            
+        community_success_rate = normalize_success_rate(scenario_stats.get('success_rate', 0))
         
         community_avg_duration = scenario_stats.get('avg_duration', 0)
         total_runs = scenario_stats.get('total_runs', 0)
         
-        if total_runs == 0:
-            return  # No meaningful data
+        # Validate community data
+        if (total_runs == 0 or 
+            not isinstance(total_runs, (int, float)) or 
+            not isinstance(community_success_rate, (int, float)) or
+            not isinstance(community_avg_duration, (int, float)) or
+            total_runs < 0 or community_success_rate < 0 or community_avg_duration < 0):
+            return  # Invalid or no meaningful data
         
         # Import Rich print for proper markup rendering
         from rich import print as rich_print
@@ -75,7 +85,7 @@ async def show_community_comparison(tool: str, scenario: str, user_duration: flo
         # Show sample size
         rich_print(f"[dim]📊 Based on {total_runs} community runs[/dim]")
         
-    except Exception as e:
+    except Exception:
         # Silently fail - don't disrupt the main test output
         pass
 
@@ -156,6 +166,9 @@ def test(
     oauth_token_file: Optional[Path] = typer.Option(
         None, "--oauth-token-file", help="Path to file containing Claude Code OAuth token"
     ),
+    yolo: bool = typer.Option(
+        False, "--yolo", help="Run scenarios without any permission prompts (DANGEROUS - use only in safe environments)"
+    ),
 ):
     """Run a test scenario against a CLI tool."""
 
@@ -163,7 +176,7 @@ def test(
         try:
             if runs == 1:
                 # Single run - use enhanced analysis
-                result = await run_test(tool, scenario, work_dir, oauth_token_file, show_progress=not verbose)
+                result = await run_test(tool, scenario, work_dir, oauth_token_file, show_progress=not verbose, yolo=yolo)
                 analysis = await enhanced_analyze_trace(
                     result["trace"],
                     result.get("scenario_text", ""),
@@ -183,7 +196,11 @@ def test(
                     scenario=result["scenario"],
                     trace=result["trace"],
                     duration=result["duration_seconds"],
-                    analysis=analysis
+                    analysis=analysis,
+                    cost_usd=result.get("cost_usd"),
+                    tool_version=result.get("tool_version"),
+                    version_detection_method=result.get("version_detection_method"),
+                    version_detection_success=result.get("version_detection_success")
                 )
                 await submitter.submit_result(test_result)
                 
@@ -198,7 +215,7 @@ def test(
                 for run_num in range(1, runs + 1):
                     typer.echo(f"Running {tool}/{scenario} - Run {run_num}/{runs}")
 
-                    result = await run_test(tool, scenario, work_dir, oauth_token_file, show_progress=not verbose)
+                    result = await run_test(tool, scenario, work_dir, oauth_token_file, show_progress=not verbose, yolo=yolo)
                     analysis = await enhanced_analyze_trace(
                         result["trace"],
                         result.get("scenario_text", ""),
@@ -217,7 +234,11 @@ def test(
                         scenario=result["scenario"],
                         trace=result["trace"],
                         duration=result["duration_seconds"],
-                        analysis=analysis
+                        analysis=analysis,
+                        cost_usd=result.get("cost_usd"),
+                        tool_version=result.get("tool_version"),
+                        version_detection_method=result.get("version_detection_method"),
+                        version_detection_success=result.get("version_detection_success")
                     )
                     await submitter.submit_result(test_result)
 
@@ -247,6 +268,9 @@ def benchmark(
     oauth_token_file: Optional[Path] = typer.Option(
         None, "--oauth-token-file", help="Path to file containing Claude Code OAuth token"
     ),
+    yolo: bool = typer.Option(
+        False, "--yolo", help="Run scenarios without any permission prompts (DANGEROUS - use only in safe environments)"
+    ),
 ):
     """Run benchmark tests for CLI tools."""
 
@@ -273,7 +297,7 @@ def benchmark(
             for scenario_file in tool_dir.glob("*.txt"):
                 scenario_name = scenario_file.stem
                 try:
-                    result = await run_test(tool_name, scenario_name, None, oauth_token_file)
+                    result = await run_test(tool_name, scenario_name, None, oauth_token_file, yolo=yolo)
                     analysis = await enhanced_analyze_trace(
                         result["trace"],
                         result.get("scenario_text", ""),
@@ -290,7 +314,11 @@ def benchmark(
                         scenario=result["scenario"],
                         trace=result["trace"],
                         duration=result["duration_seconds"],
-                        analysis=analysis
+                        analysis=analysis,
+                        cost_usd=result.get("cost_usd"),
+                        tool_version=result.get("tool_version"),
+                        version_detection_method=result.get("version_detection_method"),
+                        version_detection_success=result.get("version_detection_success")
                     )
                     await submitter.submit_result(test_result)
                 except Exception as e:
@@ -431,10 +459,12 @@ def config_get(
         # Show all config with new opt-in model
         typer.echo("Current configuration:")
         
-        # Show sharing status based on new model
+        # Show sharing status based on opt-out setting
         opted_out = config.get('opted_out', False)
         sharing_status = "disabled (opted out)" if opted_out else "enabled"
-        typer.echo(f"  sharing.enabled: {not opted_out} ({sharing_status})")
+        effective_enabled = not opted_out
+            
+        typer.echo(f"  sharing.enabled: {effective_enabled} ({sharing_status})")
         typer.echo(f"  sharing.opted_out: {opted_out}")
         
         # Show consent status
@@ -447,7 +477,8 @@ def config_get(
         # Show API configuration
         using_embedded = not config.get('api_key')
         api_key_status = "embedded key" if using_embedded else "custom key (***)"
-        typer.echo(f"  sharing.api_url: {config.get('api_url', submitter.DEFAULT_API_URL)}")
+        default_url = submitter.DEFAULT_DEVELOPMENT_API_URL if _is_development_mode() else submitter.DEFAULT_PRODUCTION_API_URL
+        typer.echo(f"  sharing.api_url: {config.get('api_url', default_url)}")
         typer.echo(f"  sharing.api_key: {api_key_status}")
         typer.echo(f"  sharing.anonymous_id: {config.get('anonymous_id', 'not generated yet')}")
 
